multidim.models.CDER.build_gaussian — GDA Toolbox v1.0 Manual

# multidim.models.CDER.build_gaussian

`CDER.` `build_gaussian`(coverlevel, adult, label, dominant_index)

  Build a Gaussian from the children of this adult in a cover-tree (using only a particular label).

  Generally, a user will never call this. It is called when `gausscoords()` decides that a CoverTree ball is work modelling.

  Parameters: | coverlevel : `multidim.covertree.CoverLevel` adult : int label : int dominant_index : int

  See also

  `gausscoords()`

#### Previous topic

multidim.models.CDER

#### Next topic

multidim.models.CDER.evaluate